Пакет ``m3-gar-client`` предоставляет панель для ввода адресов Российской Федерации с
использованием `ГАР <https://fias.nalog.ru/>`_ (Государственного адресного реестра),
готовую к использованию в проектах на базе платформы
`M3 <http://m3.bars-open.ru/>`_ компании `БАРС Груп <http://bars.group>`_.

Возможности
-----------

* Работа с сервером ГАР `m3-rest-gar <https://stash.bars-open.ru/projects/M3/repos/m3-rest-gar>`_.
* Встраивание в интерфейс веб-приложений на базе ExtJS.
* Поиск адресов в ГАР по мере ввода наименований адресных объектов (субъектов
  Федерации, населенных пунктов, улиц, зданий).

Системные требования
--------------------

* `Python <http://www.python.org/>`_ 2.7
* `Django <http://djangoproject.com/>`_ 1.4 --- 1.11
* `m3-core <https://pypi.python.org/pypi/m3-core>`_ 2.2
* `m3-ui <https://pypi.python.org/pypi/m3-ui>`_ 2.2

Установка
---------

..

  pip install m3-gar-client
